"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toFriendlyDate = exports.toSimpleISODateString = exports.getStartOfDate = exports.toDateCopy = void 0;

//@ts-check

/**
 * Turns a string into a Date if not already a Date object.
 *
 * @param {Date | string | number} date
 * @returns {Date}
 */
const toDate = date => typeof date === 'string' || typeof date === 'number' ? new Date(date) : date;
/**
 * @param {number | string} num Number to zero-pad as two-digit string
 * @returns {string}
 */


const pad = num => (num + '').padStart(2, '0');
/**
 * @param {Date | number | null} [date] If falsy will just return today
 * @returns
 */


const toDateCopy = date => {
  if (typeof date === 'number') {
    return new Date(date);
  } else if (date && date.valueOf) {
    return new Date(date.valueOf());
  }

  return new Date();
};
/**
 * @param {Date | number | null} date
 * @returns {Date}
 */


exports.toDateCopy = toDateCopy;

const getStartOfDate = date => {
  let copy = toDateCopy(date);
  copy.setMinutes(0);
  copy.setHours(0);
  copy.setSeconds(0);
  copy.setMilliseconds(0);
  return copy;
};
/**
 * @param {Date} date Date object
 * @returns {string} As YYYY-MM-DD
 */


exports.getStartOfDate = getStartOfDate;

const toSimpleISODateString = date => "".concat(date.getFullYear(), "-").concat(pad(date.getMonth() + 1), "-").concat(pad(date.getDate()));
/**
 * @param {Date | string} date
 * @returns {string}
 */


exports.toSimpleISODateString = toSimpleISODateString;

const toFriendlyDate = date => {
  date = toDate(date);
  const now = new Date();
  const inNextSevenDays = date.valueOf() - now.valueOf() < 6.048e8;
  const dayDiff = date.getDate() - now.getDate();

  if (!inNextSevenDays) {
    const isSameYear = date.getFullYear() === now.getFullYear();
    /** @type {Intl.DateTimeFormatOptions} */

    const opts = {
      month: 'long',
      day: 'numeric'
    };

    if (!isSameYear) {
      opts.year = 'numeric';
    }

    return date.toLocaleDateString(undefined, opts);
  }

  if (dayDiff === 0) {
    return 'Today';
  }

  if (dayDiff === 1) {
    return 'Tomorrow';
  }

  return date.toLocaleDateString(undefined, {
    weekday: 'long'
  });
};

exports.toFriendlyDate = toFriendlyDate;